==> com.github.weisj.jsvg.source_1.7.2.jar: com/github/weisj/jsvg/attributes/value/PercentageValue.java <==
/*
 * MIT License
 *
 * Copyright (c) 2024 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.jsvg.attributes.value;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import com.github.weisj.jsvg.animation.value.AnimatedPercentage;
import com.github.weisj.jsvg.annotations.Sealed;
import com.github.weisj.jsvg.geometry.size.MeasureContext;
import com.github.weisj.jsvg.geometry.size.Percentage;

@Sealed(permits = {Percentage.class, AnimatedPercentage.class})
public interface PercentageValue {

    static @Nullable PercentageValue derive(@Nullable PercentageValue current, @Nullable PercentageValue other) {
        if (other == null) return current;
        if (current == null) return other;
        if (other instanceof AnimatedPercentage) {
            return ((AnimatedPercentage) other).derive(current);
        }
        return other;
    }

    float get(@NotNull MeasureContext context);

    @NotNull
    PercentageValue multiply(@NotNull PercentageValue other);
}

==> com.github.weisj.jsvg.source_2.0.0.jar: com/github/weisj/jsvg/attributes/value/PercentageValue.java <==
/*
 * MIT License
 *
 * Copyright (c) 2024-2025 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.jsvg.attributes.value;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import com.github.weisj.jsvg.animation.value.AnimatedPercentage;
import com.github.weisj.jsvg.annotations.Sealed;
import com.github.weisj.jsvg.geometry.size.Percentage;
import com.github.weisj.jsvg.renderer.MeasureContext;

@Sealed(permits = {Percentage.class, AnimatedPercentage.class})
public interface PercentageValue {

    static @Nullable PercentageValue derive(@Nullable PercentageValue current, @Nullable PercentageValue other) {
        if (other == null) return current;
        if (current == null) return other;
        if (other instanceof AnimatedPercentage) {
            return ((AnimatedPercentage) other).derive(current);
        }
        return other;
    }

    float get(@NotNull MeasureContext context);

    @NotNull
    PercentageValue multiply(@NotNull PercentageValue other);
}
